@@ -5,7 +5,8 @@ import pathlib
 import subprocess
 import sys
 import time
-from datetime import datetime, timedelta
+from copy import copy
+from datetime import timedelta
 
 import yaml
 from tabulate import tabulate
@@ -15,6 +16,7 @@ from monkeyble.cli.const import MONKEYBLE_DEFAULT_CONFIG_PATH, TEST_PASSED, TEST
 from monkeyble.cli.exceptions import MonkeybleCLIException
 from monkeyble.cli.models import MonkeybleResult, ScenarioResult
 from monkeyble.cli.utils import Utils
+from monkeyble._version import __version__
 
 logger = logging.getLogger(MONKEYBLE)
 
@@ -63,14 +65,18 @@ def run_monkeyble_test(monkeyble_config):
     if "monkeyble_test_suite" not in monkeyble_config:
         raise MonkeybleCLIException(message="No 'monkeyble_test_suite' variable defined")
     list_result = list()
+    global_extra_vars = list()
+    if "monkeyble_global_extra_vars" in monkeyble_config:
+        global_extra_vars.extend(monkeyble_config["monkeyble_global_extra_vars"])
     for test_config in monkeyble_config["monkeyble_test_suite"]:
+        extra_vars = copy(global_extra_vars)
         Utils.print_info(f"Monkeyble - ansible cmd: {ansible_cmd}")
         playbook = test_config.get("playbook", None)
         new_result = MonkeybleResult(playbook)
         if playbook is None:
             raise MonkeybleCLIException(message="Missing 'playbook' key in a test")
         inventory = test_config.get("inventory", None)
-        extra_vars = test_config.get("extra_vars", None)
+        extra_vars.extend(test_config.get("extra_vars", []))
         scenarios = test_config.get("scenarios", None)
         if scenarios is None:
             raise MonkeybleCLIException(message=f"No scenarios for playbook {playbook}")
@@ -163,6 +169,8 @@ def parse_args(args):
     parser.add_argument("action", help="[test]")
     parser.add_argument("-c", "--config",
                         help="Path to the monkeyble config")
+    parser.add_argument('-v', '--version', action='version',
+                        version="Monkeyble {version}".format(version=__version__))
 
     # parse arguments from script parameters
     return parser.parse_args(args)
